@@ -10,12 +10,12 @@ import distutils.ccompiler
 
 _lib_ext = distutils.ccompiler.new_compiler().shared_lib_extension
 
-# echaimlib_path = os.path.join(
-#     os.path.dirname(os.path.realpath(__file__)),
-#     "source_c/cmake-build-debug"
-# )
+echaimlib_path = os.path.join(
+    os.path.dirname(os.path.realpath(__file__)),
+    "source_c/cmake-build-debug"
+)
 
-echaimlib_path = os.path.dirname(os.path.abspath(__file__))
+# echaimlib_path = os.path.dirname(os.path.abspath(__file__))
 
 
 def _import_libs():
